@@ -3,4 +3,4 @@
 """
 Importamos signals.py para que se "conecte" la señal que queremos
 """
-import signals
+#import signals
