@@ -24,10 +24,10 @@ class IsModerator(object):
         """ Devuelve True o False """
 
         #print request
-        print request.user
-        print view_func.__name__
+        #print request.user
+        #print view_func.__name__
         #print view_kwargs['slug']
-        print view_kwargs
+        #print view_kwargs
 
         # request.user: AnonymousUser
         # view_func.__name__: TopicDelete
