@@ -61,7 +61,7 @@ class Topic(models.Model):
     subscribers = models.ManyToManyField(User, blank=True, null=True, verbose_name=_('Subscribers'))
 
     def __unicode__(self):
-        return self.slug
+        return "%s (%s)"%(self.slug, self.forum)
 
     def save(self, *args, **kwargs):
         self.date_modified = datetime.now()
@@ -107,26 +107,6 @@ class Post(models.Model):
         verbose_name_plural = _('Posts')
 
 
-class UserProfile(models.Model):
-
-    """
-    UserProfile (extending Users), signals:
-     - http://stackoverflow.com/questions/1910359/creating-a-extended-user-profile
-    """
-
-    user = models.ForeignKey(User, unique=True, related_name='profile')
-    twitter = models.CharField(_('Twitter'), max_length=55, blank=True)
-    avatar = models.ImageField(_('Avatar'), upload_to='uploads/avatars/', blank=True)
-    signature = models.TextField(_('Signature'), blank=True, default='')
-
-    class Meta:
-        verbose_name = _('Perfil de usuario')
-        verbose_name_plural = _('Perfiles de usuario')
-
-    def __unicode__(self):
-        return self.twitter
-
-
 class Rank(models.Model):
 
     """
